# image-processing-package

## Description

The package image-processing-package is used to:

	Processing:
		- Histogram matching
		- Structural similarity
		- Resize image

	Utils:
		- Read image
		- Save image
		- Plot image
		- Plot result
		- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install image-processing-package

```bash
pip install image-processing-package
```

## Usage

```python
from image-processing-package.processing import combination
combination.find_difference()
```

## Author
Maria Gianisella

## License
[MIT](https://choosealicense.com/licenses/mit/)
